@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import pytest
 from flask import Flask
 
@@ -16,6 +15,7 @@ except ImportError:
 class CustomCache(Cache):
     pass
 
+
 class CustomSimpleCache(SimpleCache):
     pass
 
@@ -84,9 +84,9 @@ def test_app_redis_cache_backend_url_default_db(app, redis_server):
     from flask_caching.backends.rediscache import RedisCache
 
     assert isinstance(app.extensions["cache"][cache], RedisCache)
-    rconn = app.extensions["cache"][
-        cache
-    ]._write_client.connection_pool.get_connection("foo")
+    rconn = app.extensions["cache"][cache]._write_client.connection_pool.get_connection(
+        "foo"
+    )
     assert rconn.db == 0
 
 
@@ -98,9 +98,9 @@ def test_app_redis_cache_backend_url_custom_db(app, redis_server):
     }
     cache = Cache()
     cache.init_app(app, config=config)
-    rconn = app.extensions["cache"][
-        cache
-    ]._write_client.connection_pool.get_connection("foo")
+    rconn = app.extensions["cache"][cache]._write_client.connection_pool.get_connection(
+        "foo"
+    )
     assert rconn.db == 2
 
 
@@ -113,9 +113,9 @@ def test_app_redis_cache_backend_url_explicit_db_arg(app, redis_server):
     }
     cache = Cache()
     cache.init_app(app, config=config)
-    rconn = app.extensions["cache"][
-        cache
-    ]._write_client.connection_pool.get_connection("foo")
+    rconn = app.extensions["cache"][cache]._write_client.connection_pool.get_connection(
+        "foo"
+    )
     assert rconn.db == 1
 
 
